<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>ActivityHandler</name>
    <message>
        <source>Starting activity %1, which will end at %2.</source>
        <translation>Comenzando actividad %1, que acabará a las %2.</translation>
    </message>
    <message>
        <source>Activity ended: %1.</source>
        <translation>Actividad finalizada: %1.</translation>
    </message>
    <message>
        <source>None</source>
        <comment>Regarding an activity</comment>
        <translation>Ninguna</translation>
    </message>
    <message numerus="yes">
        <source>%Ln hour(s)</source>
        <translation>
            <numerusform>1 hora</numerusform>
            <numerusform>%Ln horas</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>1 minuto</numerusform>
            <numerusform>%Ln minutos</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ActivityModule</name>
    <message>
        <source>&amp;Add Activity</source>
        <translation>&amp;Añadir actividad</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutos</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Conectado</translation>
    </message>
    <message>
        <source>Free for Chat</source>
        <translatorcomment>&quot;charlar&quot;, como lo traducen en Psi</translatorcomment>
        <translation>Disponible para charlar</translation>
    </message>
    <message>
        <source>Away</source>
        <translation>Ausente</translation>
    </message>
    <message>
        <source>Extended Away</source>
        <translation>No disponible</translation>
    </message>
    <message>
        <source>Do not Disturb</source>
        <translation>No molestar</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>segundos</translation>
    </message>
    <message>
        <source>All rooms</source>
        <translation>Todas las salas</translation>
    </message>
    <message>
        <source>Several rooms</source>
        <translation>Varias salas</translation>
    </message>
    <message>
        <source>A few rooms</source>
        <translation>Unas pocas salas</translation>
    </message>
    <message>
        <source>Also to active private chats</source>
        <translation>También a conversaciones privadas activas</translation>
    </message>
    <message>
        <source>Sa&amp;ve Activity</source>
        <translation>&amp;Guardar actividad</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Maximum Times Per Day</source>
        <translation type="unfinished">Máximo de veces por día</translation>
    </message>
    <message>
        <source>Probability</source>
        <translation>Probabilidad</translation>
    </message>
    <message>
        <source>Time Range</source>
        <translation type="unfinished">Rango de horas</translation>
    </message>
    <message>
        <source>Date Range</source>
        <translation type="unfinished">Rango de fechas</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
    <message>
        <source>Set Status Type</source>
        <translation>Establecer tipo de estado</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Disponibilidad</translation>
    </message>
    <message>
        <source>Reaction Time</source>
        <translation>Tiempo de reacción</translation>
    </message>
    <message>
        <source>Descriptions</source>
        <translation>Descripciones</translation>
    </message>
    <message>
        <source>Messages Before</source>
        <translation>Mensajes antes</translation>
    </message>
    <message>
        <source>Send Messages To</source>
        <translation>Enviar mensajes a</translation>
    </message>
    <message>
        <source>&amp;Sync Activities</source>
        <translation type="unfinished">&amp;Sincronizar actividades</translation>
    </message>
    <message>
        <source>&amp;Remove Activity</source>
        <translation>&amp;Quitar actividad</translation>
    </message>
    <message>
        <source>Messages Afterwards</source>
        <translation>Mensajes después</translation>
    </message>
    <message>
        <source>New Activity</source>
        <translation>Nueva actividad</translation>
    </message>
    <message>
        <source>Activity exists</source>
        <translation>La actividad existe</translation>
    </message>
    <message>
        <source>Error: There is already an activity in the list with this name.</source>
        <translation>Error: Ya hay una actividad en la lista con este nombre.</translation>
    </message>
    <message>
        <source>Specific JIDs</source>
        <translatorcomment>FIXME: Habría que investigar si JID es masculino (IDentificador Jabber) o femenino (IDentificación Jabber)</translatorcomment>
        <translation type="obsolete">JIDs específicos</translation>
    </message>
    <message>
        <source>List of room or user addresses, separated by space</source>
        <translation>Lista de direcciones de salas o de usuarios, separadas por espacios</translation>
    </message>
    <message>
        <source>Status Messages</source>
        <translation>Mensajes de estado</translation>
    </message>
    <message numerus="yes">
        <source>Saved %Ln activities.</source>
        <translation>
            <numerusform>Se ha guardado 1 actividad.</numerusform>
            <numerusform>Se han guardado %Ln actividades.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Loaded %Ln activities.</source>
        <translation>
            <numerusform>Se ha cargado 1 actividad.</numerusform>
            <numerusform>Se han cargado %Ln actividades.</numerusform>
        </translation>
    </message>
    <message>
        <source>None of the rooms</source>
        <translation>Ninguna de las salas</translation>
    </message>
    <message>
        <source>Additional specific JIDs:</source>
        <translatorcomment>FIXME: Habría que decidir si JID es masculino (IDentificador Jabber) o femenino (IDentificación Jabber)</translatorcomment>
        <translation type="unfinished">JIDs específicos adicionales:</translation>
    </message>
</context>
<context>
    <name>ChatModule</name>
    <message>
        <source>Chat started by %1.</source>
        <comment>%1 = A nickname</comment>
        <translation>Conversación iniciada por %1.</translation>
    </message>
    <message>
        <source>New chat</source>
        <translation>Nueva conversación</translation>
    </message>
    <message>
        <source>A new chat was started by %1.</source>
        <translation type="unfinished">%1 ha iniciado una nueva conversación.</translation>
    </message>
</context>
<context>
    <name>ChatWidget</name>
    <message>
        <source>Reason:</source>
        <translation>Motivo:</translation>
    </message>
    <message>
        <source>Kicked from the room!</source>
        <translation type="unfinished">¡Expulsado de la sala!</translation>
    </message>
    <message>
        <source>Joined room %1, as %2.</source>
        <translation>Se ha entrado a la sala %1, como %2.</translation>
    </message>
    <message>
        <source>Left room %1.</source>
        <translation>Se ha salido de la sala %1.</translation>
    </message>
</context>
<context>
    <name>CommandHandler</name>
    <message>
        <source>Command from %1 in room %2: %3</source>
        <translation>Comando de %1 en la sala %2: %3</translation>
    </message>
    <message>
        <source>Command from %1: %2</source>
        <translation>Comando de %1: %2</translation>
    </message>
    <message>
        <source>The command failed.</source>
        <translation>Ha fallado el comando.</translation>
    </message>
    <message>
        <source>Error loading file %1 for command: %2</source>
        <translation>Error al cargar el archivo %1 para el comando: %2</translation>
    </message>
    <message>
        <source>Command gave no output text.</source>
        <translation type="unfinished">El comando no ha dado ningún texto de salida.</translation>
    </message>
    <message>
        <source>I don&apos;t have help about: %1</source>
        <translation>No tengo ayuda sobre: %1</translation>
    </message>
    <message>
        <source>Help for %1:</source>
        <translation>Ayuda de %1:</translation>
    </message>
    <message>
        <source>Available commands</source>
        <translation>Comandos disponibles</translation>
    </message>
    <message>
        <source>Command %1 requested without the right access level.</source>
        <translation type="unfinished">Se ha solicitado el comando %1 sin el nivel de acceso adecuado.</translation>
    </message>
    <message>
        <source>I need a parameter for the query.</source>
        <translation type="vanished">Necesito un parámetro para la consulta.</translation>
    </message>
    <message>
        <source>I don&apos;t have a match for %1</source>
        <translation type="unfinished">No tengo ninguna coincidencia para %1</translation>
    </message>
    <message>
        <source>This command is an alias to itself!</source>
        <translation>¡Este comando es un alias para sí mismo!</translation>
    </message>
    <message>
        <source>Use %1 to list the available commands.</source>
        <translation>Usa %1 para listar los comandos disponibles.</translation>
    </message>
    <message>
        <source>Use %1 [command] to get help about a specific command.</source>
        <translation>Usa %1 [comando] para recibir ayuda sobre un comando específico.</translation>
    </message>
    <message>
        <source>Started detached program successfully.</source>
        <translation type="unfinished">Se ha iniciado el programa independiente correctamente.</translation>
    </message>
    <message>
        <source>I need a parameter for the query:</source>
        <translation>Necesito un parámetro para la consulta:</translation>
    </message>
</context>
<context>
    <name>CommandModule</name>
    <message>
        <source>&amp;Add Command</source>
        <translation>&amp;Añadir comando</translation>
    </message>
    <message>
        <source>Static Message</source>
        <translation>Mensaje estático</translation>
    </message>
    <message>
        <source>Random Sentence</source>
        <translation>Frase aleatoria</translation>
    </message>
    <message>
        <source>Save &amp;Command</source>
        <translation>Guardar &amp;comando</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <source>Help Text</source>
        <translation>Texto de ayuda</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Access Level</source>
        <translation>Nivel de acceso</translation>
    </message>
    <message>
        <source>&amp;Sync Commands</source>
        <translation type="unfinished">&amp;Sincronizar comandos</translation>
    </message>
    <message>
        <source>&amp;Remove Command</source>
        <translation>&amp;Quitar comando</translation>
    </message>
    <message>
        <source>Anyone can use it</source>
        <comment>&apos;it&apos; refers to a command</comment>
        <translation>Cualquiera puede usarlo</translation>
    </message>
    <message>
        <source>Random Line from Text File</source>
        <translation>Línea aleatoria de archivo de texto</translation>
    </message>
    <message>
        <source>Run Program</source>
        <translation>Ejecutar un programa</translation>
    </message>
    <message>
        <source>Alias for another command</source>
        <translation>Alias para otro comando</translation>
    </message>
    <message>
        <source>Select File...</source>
        <translation>Selecciona archivo...</translation>
    </message>
    <message>
        <source>Static reply is empty.</source>
        <translation>La respuesta estática está vacía.</translation>
    </message>
    <message>
        <source>There are no sentences in the list.</source>
        <translation>No hay frases en la lista.</translation>
    </message>
    <message>
        <source>There is no file selected.</source>
        <translation>No hay ningún archivo seleccionado.</translation>
    </message>
    <message>
        <source>There is no program specified.</source>
        <translation>No se ha especificado ningún programa.</translation>
    </message>
    <message>
        <source>You need to enter the command this alias will execute.</source>
        <translation>Debes introducir el comando que este alias ejecutará.</translation>
    </message>
    <message>
        <source>Error validating fields</source>
        <translation>Error validando los campos</translation>
    </message>
    <message>
        <source>Select a text file</source>
        <translation>Selecciona un archivo de texto</translation>
    </message>
    <message>
        <source>Selected file does not exist.</source>
        <translation>El archivo selecionado no existe.</translation>
    </message>
    <message>
        <source>New Command</source>
        <translation>Nuevo comando</translation>
    </message>
    <message>
        <source>No file selected</source>
        <translation>Ningún archivo seleccionado</translation>
    </message>
    <message>
        <source>Command exists</source>
        <translation>El comando ya existe</translation>
    </message>
    <message>
        <source>Error: There is already a command in the list with this trigger.</source>
        <translatorcomment>FIXME</translatorcomment>
        <translation type="obsolete">Error: Ya hay un comando en la lista con este &apos;trigger&apos;.</translation>
    </message>
    <message>
        <source>Just enter a single sentence.</source>
        <translation>Introduce una única frase.</translation>
    </message>
    <message>
        <source>Add as many sentences as you want.
One of them will be selected at random as a reply.</source>
        <translation>Añade tantas frases como quieras.
Una de ellas será seleccionada al azar como respuesta.</translation>
    </message>
    <message>
        <source>A random line from the chosen file will be used as a reply.
File encoding should be UTF-8.</source>
        <translation>Se utilizará una línea aleatoria del archivo elegido como respuesta.
La codificación del archivo debe ser UTF-8.</translation>
    </message>
    <message>
        <source>Keyword-based Message</source>
        <translation>Mensaje basado en palabras clave</translation>
    </message>
    <message>
        <source>Add keywords to the list, then enter the corresponding definition for each keyword on the other side.</source>
        <translation>Añade palabras clave a la lista, luego introduce la definición correspondiente para cada palabra clave en el otro lado.</translation>
    </message>
    <message>
        <source>Enter a command to be run, with any needed parameters.
The reply will be the console output of the program, unless you specify an output pattern, and don&apos;t include the %output% variable somewhere in it.</source>
        <comment>Don&apos;t translate %output%!</comment>
        <translation type="vanished">Introduce un comando para ejecutar, con los parámetros que pueda necesitar.
La respuesta será la salida en consola del programa, a menos que especifiques un patrón de salida, y no incluyas la variable %output% en algún lugar del mismo.</translation>
    </message>
    <message>
        <source>Enter the original command that should be run when this alias is used.</source>
        <translation>Introduce el comando original que se debe ejecutar cuando se use este alias.</translation>
    </message>
    <message>
        <source>Output Pattern</source>
        <translation type="obsolete">Patrón de salida</translation>
    </message>
    <message>
        <source>Private Reply</source>
        <translation>Respuesta en privado</translation>
    </message>
    <message>
        <source>There are no keywords in the list.</source>
        <translation>No hay palabras clave en la lista.</translation>
    </message>
    <message>
        <source>A command can&apos;t be an alias of itself.</source>
        <translation>Un comando no puede ser un alias de sí mismo.</translation>
    </message>
    <message numerus="yes">
        <source>Loaded %Ln command(s).</source>
        <translation>
            <numerusform>Se ha cargado 1 comando.</numerusform>
            <numerusform>Se han cargado %Ln comandos.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Saved %Ln command(s).</source>
        <translation>
            <numerusform>Se ha guardado 1 comando.</numerusform>
            <numerusform>Se han guardado %Ln comandos.</numerusform>
        </translation>
    </message>
    <message>
        <source>The trigger word, without the prefix</source>
        <translatorcomment>FIXME</translatorcomment>
        <translation type="obsolete">La palabra &apos;trigger&apos;, sin el prefijo</translation>
    </message>
    <message>
        <source>Enter a system command line to be run, with any needed parameters.
The reply will be the console output of the program, unless you specify an output pattern, and don&apos;t include the %output% variable somewhere in it.</source>
        <comment>Don&apos;t translate %output%!</comment>
        <translation type="obsolete">Introduce una línea de comando del sistema para ejecutar, con los parámetros que pueda necesitar.
La respuesta será la salida en consola del programa, a menos que especifiques un patrón de salida, y no incluyas la variable %output% en algún lugar del mismo.</translation>
    </message>
    <message>
        <source>If the program you launch will take a long time to finish (like a GUI), you need to select the option to launch it independently, but then it will not be possible to use the program output as the reply for the command.</source>
        <translation type="unfinished">Si el programa que lanzas va a tardar mucho tiempo en terminar (como un GUI), debes seleccionar la opción de lanzarlo independientemente, pero entonces no será posible usar la salida del programa como respuesta para el comando.</translation>
    </message>
    <message>
        <source>Wait for the program to finish</source>
        <translation>Esperar a que termine el programa</translation>
    </message>
    <message>
        <source>Launch the program independently</source>
        <translation type="unfinished">Lanzar el programa independientemente</translation>
    </message>
    <message>
        <source>Optional, like: [RESULT]</source>
        <translation>Opcional, como: [RESULTADO]</translation>
    </message>
    <message>
        <source>The name, without the prefix</source>
        <translation type="unfinished">El nombre, sin el prefijo</translation>
    </message>
    <message>
        <source>Error: There is already a command in the list with this name.</source>
        <translation type="unfinished">Error: Ya hay un comando en la lista con este nombre.</translation>
    </message>
    <message>
        <source>Enter a system command line to be run, with any needed parameters.
The reply will be the console output of the program, unless you specify a reply pattern, and don&apos;t include the %output% variable somewhere in it.</source>
        <comment>Don&apos;t translate %output%!</comment>
        <translation type="unfinished">Introduce una línea de comando del sistema para ejecutar, con los parámetros que pueda necesitar.
La respuesta será la salida en consola del programa, a menos que especifiques un patrón de respuesta, y no incluyas la variable %output% en algún lugar del mismo.</translation>
    </message>
    <message>
        <source>Reply Pattern</source>
        <translation>Patrón de respuesta</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <source>Program Configuration</source>
        <translation>Configuración del programa</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Administrator JIDs</source>
        <translation>JIDs administradores</translation>
    </message>
    <message>
        <source>Command prefix</source>
        <translation>Prefijo de comandos</translation>
    </message>
    <message>
        <source>Notify new chats</source>
        <translation>Notificar nuevas conversaciones</translation>
    </message>
    <message>
        <source>Hide window on startup</source>
        <translation>Ocultar ventana al iniciar</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notificaciones</translation>
    </message>
    <message>
        <source>System Tray</source>
        <translation>Bandeja del sistema</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>seconds</source>
        <comment>Suffix next to a number</comment>
        <translation>segundos</translation>
    </message>
    <message>
        <source>Connection timeout</source>
        <translation type="unfinished">Tiempo máximo de espera de la conexión</translation>
    </message>
    <message>
        <source>Notify disconnection</source>
        <translation>Notificar desconexión</translation>
    </message>
    <message>
        <source>Connection ping interval</source>
        <translation type="unfinished">Intervalo de ping de la conexión</translation>
    </message>
</context>
<context>
    <name>ConnectionDialog</name>
    <message>
        <source>Connection Settings</source>
        <translation>Configuración de la conexión</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>XMPP Address (Jabber ID)</source>
        <translation>Dirección XMPP (ID Jabber)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <source>Connect Automatically</source>
        <translation>Conectar automáticamente</translation>
    </message>
    <message>
        <source>Resource</source>
        <translation>Recurso</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Prioridad</translation>
    </message>
    <message>
        <source>Like user@server</source>
        <translation>Como usuario@servidor</translation>
    </message>
    <message>
        <source>&amp;Connect</source>
        <translation>&amp;Conectar</translation>
    </message>
</context>
<context>
    <name>GeneralModule</name>
    <message>
        <source>Offline</source>
        <translation>Desconectado</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Desconectar</translation>
    </message>
    <message>
        <source>Current Activity:</source>
        <translation>Actividad actual:</translation>
    </message>
    <message>
        <source>Status Message:</source>
        <translation>Mensaje de estado:</translation>
    </message>
</context>
<context>
    <name>IdentityModule</name>
    <message>
        <source>&amp;Update</source>
        <translation>&amp;Actualizar</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Apodo</translation>
    </message>
    <message>
        <source>Loaded identity data for %1.</source>
        <comment>%1 is a nickname</comment>
        <translation>Datos de identidad cargados para %1.</translation>
    </message>
    <message>
        <source>Saved identity data for %1.</source>
        <comment>%1 is a nickname</comment>
        <translation>Datos de identidad guardados para %1.</translation>
    </message>
</context>
<context>
    <name>LogModule</name>
    <message>
        <source>AkariXB started.</source>
        <translation>AkariXB iniciado.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Rooms</source>
        <translation>Salas</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>About AkariXB</source>
        <translation>Acerca de AkariXB</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Conectando...</translation>
    </message>
    <message>
        <source>AkariXB is a Jabber/XMPP bot.</source>
        <translation>AkariXB es un bot para Jabber/XMPP.</translation>
    </message>
    <message>
        <source>You can talk to it, make it join chatrooms, etc.</source>
        <translation>Puedes hablarle, hacer que entre en salas de charla, etc.</translation>
    </message>
    <message>
        <source>English translation by JanKusanagi.</source>
        <comment>TRANSLATORS: Change this with your language and name. If there was another translator before you, add your name after theirs ;)</comment>
        <translation>Traducción al castellano por JanKusanagi y Kheiron.</translation>
    </message>
    <message>
        <source>Thanks to all the testers, translators and packagers, who help make AkariXB better!</source>
        <translation>¡Gracias a todos los &apos;testers&apos;, traductores y empaquetadores, que ayudan a hacer AkariXB mejor!</translation>
    </message>
    <message>
        <source>&amp;Hide Window</source>
        <translation>&amp;Ocultar ventana</translation>
    </message>
    <message>
        <source>&amp;Show Window</source>
        <translation>&amp;Mostrar ventana</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>No conectado</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Desconectar</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Registro</translation>
    </message>
    <message>
        <source>Configure AkariXB</source>
        <translation>Configurar AkariXB</translation>
    </message>
    <message>
        <source>Visit Website</source>
        <translation>Visitar sitio web</translation>
    </message>
    <message>
        <source>Report a Bug</source>
        <translation>Informar de un error</translation>
    </message>
    <message>
        <source>%1 connected.</source>
        <translation>%1 conectado.</translation>
    </message>
    <message>
        <source>Disconnected.</source>
        <translation>Desconectado.</translation>
    </message>
    <message>
        <source>Network error: %1</source>
        <translation>Error de red: %1</translation>
    </message>
    <message>
        <source>Chats</source>
        <translation type="unfinished">Conversaciones</translation>
    </message>
    <message>
        <source>Commands</source>
        <translation>Comandos</translation>
    </message>
    <message>
        <source>Conversation</source>
        <translatorcomment>FIXME</translatorcomment>
        <translation type="unfinished">Conversación</translation>
    </message>
    <message>
        <source>Activities</source>
        <translation>Actividades</translation>
    </message>
    <message>
        <source>AkariXB is Free Software, licensed under the GNU GPL license, and uses some Oxygen icons under LGPL license.</source>
        <translation>AkariXB es software libre, licenciado bajo GNU GPL, y utiliza algunos iconos Oxygen con licencia LGPL.</translation>
    </message>
    <message>
        <source>Account is not configured</source>
        <translation>La cuenta no está configurada</translation>
    </message>
    <message>
        <source>Data directory created: %1</source>
        <translation>Directorio de datos creado: %1</translation>
    </message>
    <message>
        <source>Error creating data directory: %1</source>
        <translation>Error al crear el directorio de datos: %1</translation>
    </message>
    <message>
        <source>Data directory in use: %1</source>
        <translation>Directorio de datos en uso: %1</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identidad</translation>
    </message>
    <message>
        <source>Ready.</source>
        <translation>Preparado.</translation>
    </message>
    <message>
        <source>&amp;Session</source>
        <translation>&amp;Sesión</translation>
    </message>
    <message>
        <source>S&amp;ettings</source>
        <translation>&amp;Configuración</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Ay&amp;uda</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Desconectado</translation>
    </message>
    <message>
        <source>Connection to the server was lost.</source>
        <translation>Se ha perdido la conexión con el servidor.</translation>
    </message>
    <message>
        <source>Socket Error</source>
        <translation>Error de socket</translation>
    </message>
    <message>
        <source>KeepAlive Error</source>
        <translation>Error de KeepAlive</translation>
    </message>
    <message>
        <source>XMPP Stream Error</source>
        <translation>Error de flujo XMPP</translation>
    </message>
    <message>
        <source>About XMPP</source>
        <translation>Acerca de XMPP</translation>
    </message>
    <message>
        <source>Quit?</source>
        <translation>¿Salir?</translation>
    </message>
    <message>
        <source>Are you sure?</source>
        <translation type="unfinished">¿Seguro?</translation>
    </message>
    <message>
        <source>Yes, quit AkariXB</source>
        <translation>Sí, salir de AkariXB</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
</context>
<context>
    <name>MessageHandler</name>
    <message>
        <source>Error %1 from %2: %3</source>
        <translation>Error %1 de %2: %3</translation>
    </message>
</context>
<context>
    <name>RoomModule</name>
    <message>
        <source>Add &amp;New Room</source>
        <translation>Añadir &amp;nueva sala</translation>
    </message>
    <message>
        <source>&amp;Remove Room</source>
        <translation>&amp;Quitar sala</translation>
    </message>
    <message>
        <source>Room address</source>
        <translation>Dirección de la sala</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Apodo</translation>
    </message>
    <message>
        <source>Autojoin</source>
        <translation type="unfinished">Auto-entrar</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Entrar</translation>
    </message>
    <message>
        <source>Leave</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Select a room from the list above</source>
        <translation>Selecciona una sala de la lista de arriba</translation>
    </message>
    <message>
        <source>Room Details</source>
        <translation>Detalles de la sala</translation>
    </message>
    <message>
        <source>%1 as %2</source>
        <translation type="unfinished">%1 como %2</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Room address is not valid.</source>
        <translation>La dirección de la sala no es válida.</translation>
    </message>
    <message>
        <source>Nickname is not valid.</source>
        <translation>El apodo no es válido.</translation>
    </message>
    <message>
        <source>New Room</source>
        <translation>Sala nueva</translation>
    </message>
    <message>
        <source>Leaving room %1...</source>
        <translation>Saliendo de la sala %1...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Update</source>
        <translation>&amp;Actualizar</translation>
    </message>
    <message>
        <source>Joining room %1...</source>
        <translation>Entrando a la sala %1...</translation>
    </message>
    <message>
        <source>Password, if needed</source>
        <translation>Contraseña, si se necesita</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message numerus="yes">
        <source>Loaded %Ln room(s).</source>
        <translation>
            <numerusform>Se ha cargado una sala.</numerusform>
            <numerusform>Se han cargado %Ln salas.</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StringListWidget</name>
    <message>
        <source>Enter text</source>
        <translation>Introduce el texto</translation>
    </message>
    <message>
        <source>Enter a new line of text for the list</source>
        <translation>Introduce una nueva línea de texto para la lista</translation>
    </message>
    <message>
        <source>Update the text for this item</source>
        <translation>Actualiza el texto de este elemento</translation>
    </message>
</context>
</TS>
